pub type RcuRegistration<T> = (RcuBlockInfo<T>, RcuBaseRetirePerm<T>);Expand description
Persistent identity and linear base retire permission from one registration.
pub type RcuRegistration<T> = (RcuBlockInfo<T>, RcuBaseRetirePerm<T>);Persistent identity and linear base retire permission from one registration.